@@ -22,13 +22,13 @@
 #include "history/historymanager.h"
 
 #include "global.h"
+#include "type.h"
 #include "viewfactory.h"
-#include "dndmanager.h"
 #include "sharedbuffer.h"
 #include "session.h"
 #include "command.h"
 #include "config/globalconf.h"
-
+#include "dndmanager.h"
 
 ARTICLE::ArticleAdmin *instance_articleadmin = NULL;
 
@@ -59,7 +59,7 @@ ArticleAdmin::ArticleAdmin( const std::string& url )
     get_notebook()->set_fixtab( false );
     if( ! SESSION::get_show_article_tab() ) get_notebook()->set_show_tabs( false );
 
-    setup_menu( true );
+    setup_menu();
 
     // スムーススクロール用タイマセット
     // オートスクロール時など、スムースにスクロールをするため描画用タイマーを
@@ -340,7 +340,7 @@ void ArticleAdmin::switch_admin()
 //
 // リストで与えられたページをタブで連続して開くとき(Admin::open_list())の引数セット
 //
-COMMAND_ARGS ArticleAdmin::get_open_list_args( const std::string& url )
+COMMAND_ARGS ArticleAdmin::get_open_list_args( const std::string& url, const COMMAND_ARGS& command_list )
 {
     COMMAND_ARGS command_arg;
     command_arg.arg4 = "MAIN";
@@ -516,9 +516,9 @@ void ArticleAdmin::show_toolbar()
         get_notebook()->append_toolbar( *m_search_toolbar );
 
         if( SESSION::get_show_article_toolbar() ){
-            m_toolbar->show_toolbar();
-            m_toolbarsimple->show_toolbar();
-            m_search_toolbar->show_toolbar();
+            m_toolbar->open_buttonbar();
+            m_toolbarsimple->open_buttonbar();
+            m_search_toolbar->open_buttonbar();
         }
     }
 
@@ -534,14 +534,31 @@ void ArticleAdmin::toggle_toolbar()
     if( ! m_toolbar ) return;
 
     if( SESSION::get_show_article_toolbar() ){
-        m_toolbar->show_toolbar();
-        m_toolbarsimple->show_toolbar();
-        m_search_toolbar->show_toolbar();
+
+        m_toolbar->open_buttonbar();
+        m_toolbarsimple->open_buttonbar();
+        m_search_toolbar->open_buttonbar();
+
+        switch( get_notebook()->get_current_toolbar() ){
+
+            case TOOLBAR_ARTICLE:
+                m_toolbar->show_toolbar();
+                break;
+
+            case TOOLBAR_SIMPLE:
+                m_toolbarsimple->show_toolbar();
+                break;
+
+            case TOOLBAR_SEARCH:
+                m_search_toolbar->show_toolbar();
+                break;
+        }
+
     }
     else{
-        m_toolbar->hide_toolbar();
-        m_toolbarsimple->hide_toolbar();
-        m_search_toolbar->hide_toolbar();
+        m_toolbar->close_buttonbar();
+        m_toolbarsimple->close_buttonbar();
+        m_search_toolbar->close_buttonbar();
     }
 }
 
@@ -551,20 +568,31 @@ void ArticleAdmin::toggle_toolbar()
 //
 void ArticleAdmin::open_searchbar()
 {
+    if( ! m_toolbar ) return;
+
     SKELETON::View* view = get_current_view();
     if( ! view ) return;
 
-    if( m_toolbar ){
-        m_toolbar->open_searchbar();
-        if( view->get_id_toolbar() == TOOLBAR_ARTICLE ) m_toolbar->focus_entry_search();
-    }
-    if( m_toolbarsimple ){
-        m_toolbarsimple->open_searchbar();
-        if( view->get_id_toolbar() == TOOLBAR_SIMPLE ) m_toolbarsimple->focus_entry_search();
-    }
-    if( m_search_toolbar ){
-        m_search_toolbar->open_searchbar();
-        if( view->get_id_toolbar() == TOOLBAR_SEARCH ) m_search_toolbar->focus_entry_search();
+    m_toolbar->open_searchbar();
+    m_toolbarsimple->open_searchbar();
+    m_search_toolbar->open_searchbar();
+
+    switch( get_notebook()->get_current_toolbar() ){
+
+        case TOOLBAR_ARTICLE:
+            m_toolbar->show_toolbar();
+            m_toolbar->focus_entry_search();
+            break;
+
+        case TOOLBAR_SIMPLE:
+            m_toolbarsimple->show_toolbar();
+            m_toolbarsimple->focus_entry_search();
+            break;
+
+        case TOOLBAR_SEARCH:
+            m_search_toolbar->show_toolbar();
+            m_search_toolbar->focus_entry_search();
+            break;
     }
 }
 
@@ -574,9 +602,11 @@ void ArticleAdmin::open_searchbar()
 //
 void ArticleAdmin::close_searchbar()
 {
-    if( m_toolbar ) m_toolbar->close_searchbar();
-    if( m_toolbarsimple ) m_toolbarsimple->close_searchbar();
-    if( m_search_toolbar ) m_search_toolbar->close_searchbar();
+    if( ! m_toolbar ) return;
+
+    m_toolbar->close_searchbar();
+    m_toolbarsimple->close_searchbar();
+    m_search_toolbar->close_searchbar();
 }
 
 
@@ -594,6 +624,17 @@ void ArticleAdmin::command_local( const COMMAND_ARGS& command )
     else if( command.command == "delete_popup" ) delete_popup();
     else if( command.command == "delete_all_popups" ) delete_all_popups();
 
+    // ポップアップメニューの再作成
+    else if( command.command == "reset_popupmenu" ){
+
+        std::list< SKELETON::View* > list_view = get_list_view();
+        std::list< SKELETON::View* >::iterator it = list_view.begin();
+        for( ; it != list_view.end(); ++it ){
+            SKELETON::View* view = ( *it );
+            if( view ) view->set_command( "reset_popupmenu" );
+        }
+    }
+
     // command.url を含むビューを全て再レイアウト
     else if( command.command == "relayout_views" ){
 
@@ -641,47 +682,36 @@ void ArticleAdmin::command_local( const COMMAND_ARGS& command )
 }
 
 
-
 //
-// タブのD&Dを開始
+// タブをお気に入りにドロップした時にお気に入りがデータ送信を要求してきた
 //
-void ArticleAdmin::slot_drag_begin( int page )
+void ArticleAdmin::slot_drag_data_get( Gtk::SelectionData& selection_data, const int page )
 {
+#ifdef _DEBUG    
+    std::cout << "ArticleAdmin::slot_drag_data_get page = " << page  << std::endl;
+#endif
+
     SKELETON::View* view = ( SKELETON::View* )get_notebook()->get_nth_page( page );
-    if( !view ) return;
+    if( ! view ) return;
 
-    std::string url = view->get_url();
+    const std::string url = view->get_url();
     
-    CORE::DND_Begin( get_url() );
-
     CORE::DATA_INFO info;
     info.type = TYPE_THREAD;
     info.url = DBTREE::url_readcgi( url, 0, 0 );
     info.name = DBTREE::article_subject( info.url );
+    info.data = std::string();
+    info.path = Gtk::TreePath( "0" ).to_string();
 
-    CORE::SBUF_clear_info();
     if( info.url.empty() ) return;
 
 #ifdef _DEBUG    
-    std::cout << "ArticleAdmin::slot_drag_begin " << url  << std::endl;
     std::cout << "name = " << info.name << std::endl;
-    std::cout << "url ~ " << info.url << std::endl;
-    std::cout << "type  =" << info.type << std::endl;
 #endif
 
-    CORE::SBUF_append( info );
-}
+    CORE::DATA_INFO_LIST list_info;
+    list_info.push_back( info );
+    CORE::SBUF_set_list( list_info );
 
-
-
-//
-// タブのD&D終了
-//
-void ArticleAdmin::slot_drag_end()
-{
-#ifdef _DEBUG    
-    std::cout << "ArticleAdmin::slot_drag_end\n";
-#endif
-
-    CORE::DND_End();
+    selection_data.set( DNDTARGET_FAVORITE, get_url() );
 }
