@@ -18,11 +18,12 @@
 
 #include "sound/soundmanager.h"
 
+#include "control/controlid.h"
+
 #include "command.h"
 #include "global.h"
 #include "httpcode.h"
 #include "session.h"
-#include "controlid.h"
 
 #include <sstream>
 
@@ -131,14 +132,22 @@ const bool ArticleViewMain::is_loading()
 // 更新した
 const bool ArticleViewMain::is_updated()
 {
-    int code = DBTREE::article_code( url_article() );
-    return ( code == HTTP_OK || code == HTTP_PARTIAL_CONTENT );
+
+#ifdef _DEBUG
+    std::cout << "ArticleViewMain::is_updated " << url_article() << " " << ( get_article()->get_status() & STATUS_UPDATED ) << std::endl;
+#endif
+
+    return ( get_article()->get_status() & STATUS_UPDATED );
 }
 
 
 // 更新チェックして更新可能か
 const bool ArticleViewMain::is_check_update()
 {
+#ifdef _DEBUG
+    std::cout << "ArticleViewMain::is_check_update " << url_article() << " " << ( get_article()->get_status() & STATUS_UPDATE ) << std::endl;
+#endif
+
     return ( get_article()->get_status() & STATUS_UPDATE );
 }
 
@@ -166,7 +175,7 @@ void ArticleViewMain::exec_reload()
 
     // オフライン
     if( ! SESSION::is_online() ){
-        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
         mdiag.run();
 
         if( get_live() ) ARTICLE::get_admin()->set_command( "live_stop", get_url() );
@@ -279,7 +288,8 @@ void ArticleViewMain::show_view()
     if( ! get_live() && SESSION::is_online() ) m_playsound = true;
 
     // 差分 download 開始
-    get_article()->download_dat( false );
+    const bool check_update = false;
+    get_article()->download_dat( check_update );
     if( is_loading() ){
 #ifdef _DEBUG
         std::cout << "loading start\n";
@@ -351,13 +361,6 @@ void ArticleViewMain::update_view()
 //
 void ArticleViewMain::update_finish()
 {
-    std::string str_stat;
-    if( is_old() ) str_stat = "[ DAT落ち 又は 移転しました ] ";
-    if( is_check_update() ) str_stat += "[ 更新可能です ] ";
-    if( is_broken() ) str_stat += "[ 壊れています ] ";
-
-    if( ! DBTREE::article_ext_err( url_article() ).empty() ) str_stat += "[ " + DBTREE::article_ext_err( url_article() ) + " ] ";
-
     // スレラベルセット
     std::string str_tablabel;
     if( is_broken() ) str_tablabel = "[ 壊れています ]  ";
@@ -385,19 +388,8 @@ void ArticleViewMain::update_finish()
     const int number_new = DBTREE::article_number_new( url_article() );
     if( ! number_new ) drawarea()->hide_separator_new();
 
-    // ステータス表示
-    std::ostringstream ss_tmp;
-    ss_tmp << DBTREE::article_str_code( url_article() )
-           << " [ 全 " << number_load
-           << " / 新着 " << number_new;
-
-    if( DBTREE::article_write_time( url_article() ) ) ss_tmp << " / 最終書込 " << DBTREE::article_write_date( url_article() );
-
-    ss_tmp << " / 速度 " << DBTREE::article_get_speed( url_article() )
-           << " / " << DBTREE::article_lng_dat( url_article() )/1024 << " k ] "
-           << str_stat;
-
-    set_status( ss_tmp.str() );
+    // ステータス更新 (実況中はフォーカスされてなくても表示)
+    create_status_message();
     ARTICLE::get_admin()->set_command( "set_status", get_url(), get_status(), ( get_live() ? "force" : "" ) );
 
     // タイトルセット
@@ -428,7 +420,7 @@ void ArticleViewMain::update_finish()
     }
 
     // ロード後に新着へジャンプ
-    else if( CONFIG::get_jump_new_after_reload() && number_new && ! drawarea()->is_separator_on_screen() ){
+    else if( CONFIG::get_jump_new_after_reload() && number_new ){
 #ifdef _DEBUG
         std::cout << "jump_new_after_reload\n";
 #endif
@@ -470,24 +462,53 @@ void ArticleViewMain::update_finish()
 }
 
 
+//
+// ステータスに表示する文字列作成
+//
+void ArticleViewMain::create_status_message()
+{
+#ifdef _DEBUG
+    std::cout << "ArticleViewMain::create_status_message\n";
+#endif
+
+    const int number_load = DBTREE::article_number_load( url_article() );
+    const int number_new = DBTREE::article_number_new( url_article() );
+
+    std::ostringstream ss_tmp;
+    ss_tmp << DBTREE::article_str_code( url_article() )
+           << " [ 全 " << number_load
+           << " / 新着 " << number_new;
+
+    if( DBTREE::article_write_time( url_article() ) ) ss_tmp << " / 最終書込 " << DBTREE::article_write_date( url_article() );
+
+    std::string str_stat;
+    if( is_old() ) str_stat = "[ DAT落ち 又は 移転しました ] ";
+    if( is_check_update() ) str_stat += "[ 更新可能です ] ";
+    if( is_broken() ) str_stat += "[ 壊れています ] ";
+
+    if( ! DBTREE::article_ext_err( url_article() ).empty() ) str_stat += "[ " + DBTREE::article_ext_err( url_article() ) + " ] ";
+
+    ss_tmp << " / 速度 " << DBTREE::article_get_speed( url_article() )
+           << " / " << DBTREE::article_lng_dat( url_article() )/1024 << " k ] "
+           << str_stat;
+
+    set_status( ss_tmp.str() );
+}
+
+
 //
 // 板一覧との切り替え方法説明ダイアログ表示
 //
 void ArticleViewMain::show_instruct_diag()
 {
-    const int mrg = 16;
-
-    SKELETON::MsgDiag mdiag( NULL, 
-        "スレビューからスレ一覧表示に戻る方法として\n\n(1) マウスジェスチャを使う\n(マウス右ボタンを押しながら左または下にドラッグして右ボタンを離す)\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレ一覧アイコンを押す\n\n(5) 表示メニューからスレ一覧を選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。" );
-    Gtk::HBox hbox;
-    Gtk::CheckButton chkbutton( "今後表示しない(_D)", true );
-    hbox.pack_start( chkbutton, Gtk::PACK_EXPAND_WIDGET, mrg );
-    mdiag.get_vbox()->pack_start( hbox, Gtk::PACK_SHRINK );
+    SKELETON::MsgCheckDiag mdiag( get_parent_win(), 
+                                  "スレビューからスレ一覧表示に戻る方法として\n\n(1) マウスジェスチャを使う\n(マウス右ボタンを押しながら左または下にドラッグして右ボタンを離す)\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレ一覧アイコンを押す\n\n(5) 表示メニューからスレ一覧を選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。"
+                                  , "今後表示しない(_D)"
+        );
     mdiag.set_title( "ヒント" );
-    mdiag.show_all_children();
     mdiag.run();
 
-    if( chkbutton.get_active() ) CONFIG::set_instruct_tglart( false );
+    if( mdiag.get_chkbutton().get_active() ) CONFIG::set_instruct_tglart( false );
     m_show_instdialog = false;
 }
 
@@ -499,7 +520,7 @@ void ArticleViewMain::show_instruct_diag()
 void ArticleViewMain::relayout()
 {
 #ifdef _DEBUG
-    std::cout << "ArticleViewMain::relayout\n";
+    std::cout << "ArticleViewMain::relayout " << DBTREE::article_subject( url_article() ) << std::endl;;
 #endif
 
     hide_popup( true );
@@ -514,6 +535,10 @@ void ArticleViewMain::relayout()
     if( num_reserve ) drawarea()->goto_num( num_reserve );
     else if( seen ) drawarea()->goto_num( seen );
     drawarea()->redraw_view();
+
+    // ステータス更新
+    create_status_message();
+    ARTICLE::get_admin()->set_command( "set_status", get_url(), get_status() );
 }
 
 
@@ -528,7 +553,7 @@ void ArticleViewMain::live_start()
 
     // オフライン
     if( ! SESSION::is_online() ){
-        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
         mdiag.run();
         return;
     }
