@@ -164,6 +164,11 @@ const bool ConfigItems::load()
     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
     idpopup_by_mo = cf.get_option( "idpopup_by_mo", CONF_IDPOPUP_BY_MO );
 
+    // 画像のスムージングレベル(0-2, 2が最も高画質かつ低速)
+    imgemb_interp = cf.get_option( "imgemb_interp", CONF_IMGEMB_INTERP );
+    imgmain_interp = cf.get_option( "imgmain_interp", CONF_IMGMAIN_INTERP );
+    imgpopup_interp = cf.get_option( "imgpopup_interp", CONF_IMGPOPUP_INTERP );
+
     // 画像ポップアップサイズ
     imgpopup_width = cf.get_option( "imgpopup_width", CONF_IMGPOPUP_WIDTH );
     imgpopup_height = cf.get_option( "imgpopup_height", CONF_IMGPOPUP_HEIGHT );
@@ -204,9 +209,12 @@ const bool ConfigItems::load()
     // JD ホームページのアドレス
     url_jdhp = cf.get_option( "url_jdhp", CONF_URL_JDHP );
 
-    // 2chの認証サーバ
+    // 2chの認証サーバのアドレス
     url_login2ch = cf.get_option( "url_login2ch", CONF_LOGIN2CH );
 
+    // p2の認証サーバのアドレス
+    url_loginp2 = cf.get_option( "url_loginp2", CONF_LOGINP2 );
+
     // bbsmenu.htmlのURL
     url_bbsmenu = cf.get_option( "url_bbsmenu", CONF_URL_BBSMENU );
 
@@ -421,9 +429,15 @@ const bool ConfigItems::load()
     // スレをお気に入りに追加したときにしおりをセットする
     bookmark_drop = cf.get_option( "bookmark_drop", CONF_BOOKMARK_DROP );
 
+    // お気に入りの更新チェック時に板の更新もチェックする
+    check_update_board  = cf.get_option( "check_update_board", CONF_CHECK_UPDATE_BOARD );
+
     // Ctrl+qでウィンドウを閉じない
     disable_close = cf.get_option( "disable_close", CONF_DISABLE_CLOSE );
 
+    // まちBBSの取得に offlaw.cgi を使用する
+    use_machi_offlaw = cf.get_option( "use_machi_offlaw", CONF_USE_MACHI_OFFLAW );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     migemodict_path = cf.get_option( "migemodict_path", CONF_MIGEMO_PATH );
@@ -459,6 +473,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "manage_winpos", manage_winpos );
     cf.update( "url_jdhp", url_jdhp );
     cf.update( "url_login2ch", url_login2ch );
+    cf.update( "url_loginp2", url_loginp2 );
     cf.update( "url_bbsmenu", url_bbsmenu );
     cf.update( "use_link_as_board", use_link_as_board );
     cf.update( "show_movediag", show_movediag );
@@ -521,6 +536,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "namepopup_by_mo", namepopup_by_mo );
     cf.update( "idpopup_by_mo", idpopup_by_mo );
 
+    cf.update( "imgemb_interp", imgemb_interp );
+    cf.update( "imgmain_interp", imgmain_interp );
+    cf.update( "imgpopup_interp", imgpopup_interp );
     cf.update( "imgpopup_width", imgpopup_width );
     cf.update( "imgpopup_height", imgpopup_height );
     cf.update( "use_image_popup", use_image_popup );
@@ -660,7 +678,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "threshold_next", threshold_next );
     cf.update( "replace_favorite_next", replace_favorite_next );
     cf.update( "bookmark_drop", bookmark_drop );
+    cf.update( "check_update_board", check_update_board );
     cf.update( "disable_close", disable_close );
+    cf.update( "use_machi_offlaw", use_machi_offlaw );
 
 #ifdef HAVE_MIGEMO_H
     cf.update( "migemodict_path", migemodict_path );
