@@ -101,6 +101,11 @@ namespace CONFIG
         // IDの上にマウスオーバーしたときにIDをポップアップ表示する
         bool idpopup_by_mo;
 
+        // 画像のスムージングレベル(0-2, 2が最も高画質かつ低速)
+        int imgemb_interp;
+        int imgmain_interp;
+        int imgpopup_interp;
+
         // 画像ポップアップサイズ
         int imgpopup_width;
         int imgpopup_height;
@@ -143,9 +148,12 @@ namespace CONFIG
         // JD ホームページのアドレス
         std::string url_jdhp;
 
-        // 2chの認証サーバ
+        // 2chの認証サーバのアドレス
         std::string url_login2ch;
 
+        // p2の認証サーバのアドレス
+        std::string url_loginp2;
+
         // bbsmenu.htmlのURL
         std::string url_bbsmenu;
 
@@ -355,9 +363,15 @@ namespace CONFIG
         // スレをお気に入りに追加したときにしおりをセットする
         bool bookmark_drop;
 
+        // お気に入りの更新チェック時に板の更新もチェックする
+        bool check_update_board;
+
         // Ctrl+qでウィンドウを閉じない
         bool disable_close;
 
+        // まちBBSの取得に offlaw.cgi を使用する
+        bool use_machi_offlaw;
+
 #ifdef HAVE_MIGEMO_H
         // migemo-dictの場所
         std::string migemodict_path;
