@@ -114,6 +114,8 @@ const int CONFIG::ref_prefix_space(){ return get_confitem()->ref_prefix_space; }
 const std::string& CONFIG::get_url_jdhp() { return get_confitem()->url_jdhp; }
 
 const std::string& CONFIG::get_url_login2ch() { return get_confitem()->url_login2ch; }
+const std::string& CONFIG::get_url_loginp2() { return get_confitem()->url_loginp2; }
+
 const std::string& CONFIG::get_url_bbsmenu() { return get_confitem()->url_bbsmenu; }
 
 const bool CONFIG::use_link_as_board(){ return get_confitem()->use_link_as_board; }
@@ -167,7 +169,7 @@ void CONFIG::set_proxy_port_for_data( int port ){ get_confitem()->proxy_port_for
 const int CONFIG::get_loader_bufsize(){ return get_confitem()->loader_bufsize; }
 const int CONFIG::get_loader_timeout(){ return get_confitem()->loader_timeout; }
 const int CONFIG::get_loader_timeout_post(){ return get_confitem()->loader_timeout_post; }
-const int CONFIG::get_loader_timeout_img(){ return get_confitem()->loader_timeout_img; }
+const int CONFIG::get_loader_timeout_data(){ return get_confitem()->loader_timeout_img; } // 旧 get_loader_timeout_img() 関数
 const int CONFIG::get_loader_timeout_checkupdate(){ return get_confitem()->loader_timeout_checkupdate; }
 
 const bool CONFIG::get_use_ipv6(){ return get_confitem()->use_ipv6; }
@@ -183,6 +185,10 @@ const bool CONFIG::get_refpopup_by_mo(){ return get_confitem()->refpopup_by_mo;
 const bool CONFIG::get_namepopup_by_mo(){ return get_confitem()->namepopup_by_mo; }
 const bool CONFIG::get_idpopup_by_mo(){ return get_confitem()->idpopup_by_mo; }
 
+const int CONFIG::get_imgemb_interp(){ return get_confitem()->imgemb_interp; }
+const int CONFIG::get_imgmain_interp(){ return get_confitem()->imgmain_interp; }
+const int CONFIG::get_imgpopup_interp(){ return get_confitem()->imgpopup_interp; }
+
 const int CONFIG::get_imgpopup_width(){ return get_confitem()->imgpopup_width; }
 const int CONFIG::get_imgpopup_height(){ return get_confitem()->imgpopup_height; }
 
@@ -352,18 +358,18 @@ const int CONFIG::get_abone_hour_thread(){ return get_confitem()->abone_hour_thr
 void CONFIG::set_abone_hour_thread( const int hour ){ get_confitem()->abone_hour_thread = hour; }
 
 
-std::list< std::string >& CONFIG::get_list_abone_name(){ return get_confitem()->list_abone_name; }
-std::list< std::string >& CONFIG::get_list_abone_word(){ return get_confitem()->list_abone_word; }
-std::list< std::string >& CONFIG::get_list_abone_regex(){ return get_confitem()->list_abone_regex; }
+const std::list< std::string >& CONFIG::get_list_abone_name(){ return get_confitem()->list_abone_name; }
+const std::list< std::string >& CONFIG::get_list_abone_word(){ return get_confitem()->list_abone_word; }
+const std::list< std::string >& CONFIG::get_list_abone_regex(){ return get_confitem()->list_abone_regex; }
 
-void CONFIG::set_list_abone_name( std::list< std::string >& name )
+void CONFIG::set_list_abone_name( const std::list< std::string >& name )
 {
     // 前後の空白と空白行を除く
     get_confitem()->list_abone_name = MISC::remove_space_from_list( name );
     get_confitem()->list_abone_name = MISC::remove_nullline_from_list( get_confitem()->list_abone_name );
 }
 
-void CONFIG::set_list_abone_word( std::list< std::string >& word )
+void CONFIG::set_list_abone_word( const std::list< std::string >& word )
 {
     // 前後の空白と空白行を除く
     get_confitem()->list_abone_word = MISC::remove_space_from_list( word );
@@ -371,7 +377,7 @@ void CONFIG::set_list_abone_word( std::list< std::string >& word )
 }
 
 
-void CONFIG::set_list_abone_regex( std::list< std::string >& regex )
+void CONFIG::set_list_abone_regex( const std::list< std::string >& regex )
 {
     // 前後の空白と空白行を除く
     get_confitem()->list_abone_regex = MISC::remove_space_from_list( regex );
@@ -379,9 +385,9 @@ void CONFIG::set_list_abone_regex( std::list< std::string >& regex )
 }
 
 const bool CONFIG::get_abone_transparent(){ return get_confitem()->abone_transparent; }
-void CONFIG::set_abone_transparent( bool set ){ get_confitem()->abone_transparent = set; }
+void CONFIG::set_abone_transparent( const bool set ){ get_confitem()->abone_transparent = set; }
 const bool CONFIG::get_abone_chain(){ return get_confitem()->abone_chain; }
-void CONFIG::set_abone_chain( bool set ){ get_confitem()->abone_chain = set; }
+void CONFIG::set_abone_chain( const bool set ){ get_confitem()->abone_chain = set; }
 
 const bool CONFIG::get_expand_sidebar(){ return get_confitem()->expand_sidebar; }
 
@@ -397,9 +403,16 @@ const bool CONFIG::get_replace_favorite_next(){ return get_confitem()->replace_f
 // スレをお気に入りに追加したときにしおりをセットする
 const bool CONFIG::get_bookmark_drop(){ return get_confitem()->bookmark_drop; }
 
+// お気に入りの更新チェック時に板の更新もチェックする
+const bool CONFIG::get_check_update_board(){ return get_confitem()->check_update_board; }
+
 // Ctrl+qでウィンドウを閉じない
 const bool CONFIG::get_disable_close(){ return get_confitem()->disable_close; }
 
+// まちBBSの取得に offlaw.cgi を使用する
+const bool CONFIG::get_use_machi_offlaw(){ return get_confitem()->use_machi_offlaw; }
+void CONFIG::set_use_machi_offlaw( const bool set ){ get_confitem()->use_machi_offlaw = set; }
+
 
 #ifdef HAVE_MIGEMO_H
 const std::string& CONFIG::get_migemodict_path() { return get_confitem()->migemodict_path; }
