@@ -51,6 +51,15 @@ namespace MESSAGE
     class MessageAdmin;
 }
 
+
+enum
+{
+    IMGVIEW_WINDOW = 0,
+    IMGVIEW_EMB,
+    IMGVIEW_NO
+};
+
+
 namespace CORE
 {
     class MainToolBar;
@@ -103,7 +112,8 @@ namespace CORE
         Gtk::Widget* get_toplevel();
 
         // init = true なら初回起動
-        void run( bool init );        
+        // skip_setupdiag = true なら初回起動時にセットアップダイアログ非表示
+        void run( const bool init, const bool skip_setupdiag );        
 
         void set_command( const COMMAND_ARGS& command );
 
@@ -131,102 +141,20 @@ namespace CORE
 
         void slot_activate_menubar();
 
-        void slot_toggle_save_post_log();
-        void slot_toggle_save_post_history();
-        void slot_toggle_use_mosaic();
-        void slot_toggle_use_imgpopup();
-        void slot_toggle_use_inlineimg();
-        void slot_toggle_show_ssspicon();
-        void slot_delete_all_images();
-
-        void slot_clear_privacy();
         void slot_clear_board();
         void slot_clear_thread();
         void slot_clear_close();
         void slot_clear_search();
         void slot_clear_name();
         void slot_clear_mail();
-        void slot_clear_post_log();
-        void slot_clear_post_history();
 
-        void slot_changefont_main();
-        void slot_changefont_popup();
-        void slot_changefont_tree();
-        void slot_changecolor_char();
-        void slot_changecolor_back();
-        void slot_changecolor_char_tree();
-        void slot_changecolor_back_tree();
         bool open_color_diag( std::string title, int id );
         
-        void slot_setup_fontcolor();
-        void slot_setup_key();
-        void slot_setup_mouse();
-        void slot_setup_button();
-        void slot_setup_proxy();
-        void slot_setup_passwd();
-        void slot_toggle_ipv6();
-        void slot_setup_mainitem();
-        void slot_setup_sidebaritem();
-        void slot_setup_boarditemcolumn();
-        void slot_setup_boarditem();
-        void slot_setup_articleitem();
-        void slot_setup_msgitem();
-        void slot_board_pref();
-        void slot_article_pref();
-        void slot_image_pref();
-        void slot_usrcmd_pref();
-        void slot_filter_pref();
-        void slot_setup_browser();
-        void slot_setup_abone();
-        void slot_setup_abone_thread();
-        void slot_toggle_abone_transp_chain();
-        void slot_setup_live();
-
-        void slot_show_bbs();
-        void slot_show_old2ch();
-        void slot_show_manual();
-        void slot_aboutconfig();
-        void slot_show_about();
-        void slot_quit();
-        void slot_reload_list();
-        void slot_check_update_root();
-        void slot_edit_favorite();
-        void slot_check_update_open_root();
-        void slot_cancel_check_update();
-        void slot_save_favorite();
-        void slot_toggle_online();
-        void slot_toggle_login2ch();
-        void slot_toggle_loginbe();
-        void slot_toggle_loginp2();
         void toggle_menubar();
         void toggle_flat_button();
         void toggle_post_mark();
         void toggle_sidebar();
-        void slot_search_cache_board();
-        void slot_search_cache();
-        void slot_search_title();
-        void slot_show_postlog();
-        void slot_live_start_stop();
         void slot_show_hide_leftpane( int mode );
-        void slot_toggle_toolbarpos( int pos );
-        void slot_toggle_toolbarbbslist();
-        void slot_toggle_toolbararticle();
-        void slot_toggle_toolbarboard();
-        void slot_toggle_tabboard();
-        void slot_toggle_tabarticle();
-        void slot_toggle_2pane();
-        void slot_toggle_3pane();
-        void slot_toggle_v3pane();
-        void slot_toggle_winmsg();
-        void slot_toggle_embmsg();
-        void slot_toggle_imgview( const int mode );
-        void slot_toggle_oldarticle();
-        void slot_toggle_tabbutton();
-        void slot_toggle_popupwarpmode();
-        void slot_shortmargin_popup();
-        void slot_toggle_emacsmode();
-        void slot_toggle_restore_views();
-        void slot_toggle_fold_message();
 
         virtual void callback_dispatch();
 
@@ -282,6 +210,100 @@ namespace CORE
         // 画像インジケータ表示/非表示
         void show_imagetab();
         void hide_imagetab();
+
+        // 板にdatファイルをインポートする
+        void import_dat( const std::string& url_board, const std::list< std::string > list_files );
+
+
+        //
+        // メニュー関係( menuslots.cpp の中に記述)
+        //
+        void slot_toggle_online();
+        void slot_toggle_login2ch();
+        void slot_toggle_loginbe();
+        void slot_toggle_loginp2();
+        void slot_reload_list();
+        void slot_save_favorite();
+        void slot_quit();
+        ///
+        void slot_toggle_toolbarpos( int pos );
+        void slot_toggle_toolbarbbslist();
+        void slot_toggle_toolbarboard();
+        void slot_toggle_toolbararticle();
+        void slot_toggle_tabboard();
+        void slot_toggle_tabarticle();
+        void slot_toggle_2pane();
+        void slot_toggle_3pane();
+        void slot_toggle_v3pane();
+        void slot_toggle_winmsg();
+        void slot_toggle_embmsg();
+        void slot_toggle_imgview( const int mode );
+        void slot_toggle_use_imgpopup();
+        void slot_toggle_use_inlineimg();
+        void slot_toggle_show_ssspicon();
+        void slot_setup_boarditemcolumn();
+        void slot_setup_mainitem();
+        void slot_setup_sidebaritem();
+        void slot_setup_boarditem();
+        void slot_setup_articleitem();
+        void slot_setup_msgitem();
+        //
+        void slot_board_pref();
+        void slot_article_pref();
+        void slot_image_pref();
+        void slot_toggle_oldarticle();
+        void slot_toggle_restore_views();
+        void slot_toggle_fold_message();
+        void slot_toggle_save_post_log();
+        void slot_toggle_save_post_history();
+        void slot_toggle_use_mosaic();
+        void slot_toggle_use_machi_offlaw();
+        void slot_toggle_tabbutton();
+        void slot_toggle_popupwarpmode();
+        void slot_shortmargin_popup();
+        void slot_toggle_emacsmode();
+        void slot_setup_mouse();
+        void slot_setup_key();
+        void slot_setup_button();
+        void slot_changefont_main();
+        void slot_changefont_popup();
+        void slot_changefont_tree();
+        void slot_changecolor_char();
+        void slot_changecolor_back();
+        void slot_changecolor_char_tree();
+        void slot_changecolor_back_tree();
+        void slot_setup_fontcolor();
+        void slot_setup_proxy();
+        void slot_setup_browser();
+        void slot_setup_passwd();
+        void slot_toggle_ipv6();
+        void slot_setup_abone();
+        void slot_setup_abone_thread();
+        void slot_toggle_abone_transp_chain();
+        void slot_setup_live();
+        void slot_usrcmd_pref();
+        void slot_filter_pref();
+        void slot_aboutconfig();
+        void slot_clear_privacy();
+        void slot_clear_post_log();
+        void slot_clear_post_history();
+        void slot_delete_all_images();
+        //
+        void slot_live_start_stop();
+        void slot_search_cache_board();
+        void slot_search_cache();
+        void slot_search_title();
+        void slot_check_update_root();
+        void slot_check_update_open_root();
+        void slot_cancel_check_update();
+        void slot_edit_favorite();
+        void slot_show_postlog();
+        void slot_import_dat();
+        //
+        void slot_show_bbs();
+        void slot_show_old2ch();
+        void slot_show_manual();
+        void slot_show_about();
     };
 
     Core* get_instance();
