@@ -46,11 +46,11 @@ m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); \
 #define GET_INFOVALUE(target,targetname) \
 do { \
 target = std::string(); \
-option = targetname; \
+const int n = strlen( targetname ); \
 it2 = it; \
-while( it2 != lines.end() && ( *it2 ).find( option ) != 0 ) ++it2; \
+while( it2 != lines.end() && ( ( *it2 ).c_str()[ 0 ] != targetname[ 0 ] || strncmp( ( *it2 ).c_str(), targetname, n ) != 0 ) ) ++it2; \
 if( it2 != lines.end() ){ \
-    target = ( *it2 ).substr( option.length() ); \
+    target = ( *it2 ).substr( n ); \
     it = ++it2; \
 } } while( false )
 
@@ -75,8 +75,9 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_number_max( MAX_RESNUMBER ),
       m_write_fixname( 0 ),
       m_write_fixmail( 0 ),
-      m_abone_transparent( 0 ),
-      m_abone_chain( 0 ),
+      m_abone_transparent( false ),
+      m_abone_chain( false ),
+      m_abone_age( false ),
       m_bookmarked_thread( false ),
       m_cached( cached ),
       m_read_info( 0 ),
@@ -120,6 +121,13 @@ const bool ArticleBase::empty()
 }
 
 
+// ID がこのスレのものかどうか
+const bool ArticleBase::equal( const std::string& datbase, const std::string& id )
+{
+    return ( id == m_id );
+}
+
+
 //
 // 移転する前のオリジナルのURL
 //
@@ -433,7 +441,7 @@ void ArticleBase::set_number( const int number )
         m_number = number;
 
         // キャッシュがあって更新可能になった場合は
-        // スレの場合はお気に入りとスレタブのアイコンを更新
+        // お気に入りとスレビューのタブのアイコンに更新マークを表示
         if( is_cached() && !( m_status & STATUS_UPDATE ) && m_number_load < m_number ) show_updateicon( true );
     }
 }
@@ -511,7 +519,7 @@ void ArticleBase::set_bookmarked_thread( const bool bookmarked )
 //
 const bool ArticleBase::enable_load()
 {
-    return ( is_cached() && ( m_status & STATUS_UPDATE ) );
+    return ( is_cached() && ( m_status & STATUS_UPDATE ) && ! ( m_status & STATUS_OLD ) );
 }
 
 
@@ -573,7 +581,7 @@ void ArticleBase::update_abone()
     if( ! m_nodetree ) return;
 
     get_nodetree()->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
-                                     m_abone_transparent, m_abone_chain );
+                                     m_abone_transparent, m_abone_chain, m_abone_age );
 
     get_nodetree()->update_abone_all();
 }
@@ -583,10 +591,12 @@ void ArticleBase::update_abone()
 //
 // あぼーん状態のリセット(情報セットと状態更新)
 //
-void ArticleBase::reset_abone( std::list< std::string >& ids, std::list< std::string >& names
-                               ,std::list< std::string >& words,  std::list< std::string >& regexs
-                               ,const std::vector< char >& vec_abone_res
-                               ,const bool transparent, const bool chain )
+void ArticleBase::reset_abone( const std::list< std::string >& ids,
+                               const std::list< std::string >& names,
+                               const std::list< std::string >& words,
+                               const std::list< std::string >& regexs,
+                               const std::vector< char >& vec_abone_res,
+                               const bool transparent, const bool chain, const bool age )
 {
     if( empty() ) return;
 
@@ -620,6 +630,7 @@ void ArticleBase::reset_abone( std::list< std::string >& ids, std::list< std::st
     
     m_abone_transparent = transparent;
     m_abone_chain = chain;
+    m_abone_age = age;
 
     update_abone();
 
@@ -717,7 +728,7 @@ void ArticleBase::set_abone_res( const int number, const bool set )
 //
 // 透明あぼーん更新
 //
-void ArticleBase::set_abone_transparent( bool set )
+void ArticleBase::set_abone_transparent( const bool set )
 {
     if( empty() ) return;
 
@@ -732,7 +743,7 @@ void ArticleBase::set_abone_transparent( bool set )
 //
 // 連鎖あぼーん更新
 //
-void ArticleBase::set_abone_chain( bool set )
+void ArticleBase::set_abone_chain( const bool set )
 {
     if( empty() ) return;
 
@@ -744,6 +755,20 @@ void ArticleBase::set_abone_chain( bool set )
 } 
 
 
+//
+// ageあぼーん更新
+//
+void ArticleBase::set_abone_age( const bool set )
+{
+    if( empty() ) return;
+
+    m_abone_age = set;
+
+    update_abone();
+
+    m_save_info = true;
+} 
+
 
 //
 // ブックマークの数
@@ -865,7 +890,7 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
 
         // あぼーん情報のコピー
         m_nodetree->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
-                                     m_abone_transparent, m_abone_chain );
+                                     m_abone_transparent, m_abone_chain, m_abone_age );
 
         // 書き込み情報のコピー
         m_nodetree->copy_post_info( m_vec_posted );
@@ -982,7 +1007,7 @@ void ArticleBase::download_dat( const bool check_update )
 #ifdef _DEBUG
         std::cout << "old !\n";
 #endif       
-        CORE::core_set_command( "toggle_favorite_icon", m_url );
+        CORE::core_set_command( "toggle_favorite_articleicon", m_url );
 
         // update_article_finish コマンドを送らないとキャッシュが無くて
         // dat落ちしているスレのタブが空白になる
@@ -1060,8 +1085,9 @@ void ArticleBase::copy_article_info( const std::string& url_src )
     std::vector< char > vec_abone_res;
     const bool transparent = DBTREE::get_abone_transparent( url_src );
     const bool chain = DBTREE::get_abone_chain( url_src );
+    const bool age = DBTREE::get_abone_age( url_src );
 
-    reset_abone( ids, names ,words, regexs, vec_abone_res, transparent, chain );
+    reset_abone( ids, names ,words, regexs, vec_abone_res, transparent, chain, age );
 }
 
 
@@ -1109,18 +1135,19 @@ void ArticleBase::slot_load_finished()
     slot_node_updated();
 
     // HTTPコード取得
-    int old_code = m_code;
+    const int old_code = m_code;
     m_code = m_nodetree->get_code();
+    m_status &= ~STATUS_UPDATED;
 
     // 状態更新
-    int old_status = m_status;
+    const int old_status = m_status;
     if( m_code != HTTP_ERR ){
 
         // DAT落ち
         if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND ){
             m_status &= ~STATUS_NORMAL;
             m_status |= STATUS_OLD;
-            CORE::core_set_command( "toggle_favorite_icon", m_url );
+            CORE::core_set_command( "toggle_favorite_articleicon", m_url );
         }
 
         // 既にDAT落ち状態では無いときは通常状態にする
@@ -1143,11 +1170,15 @@ void ArticleBase::slot_load_finished()
         std::cout << "check_update code = " << m_code << std::endl;
 #endif
 
-        // スレタブとお気に入りとスレ一覧のアイコンを更新
+        // スレタブとお気に入りとスレ一覧のアイコンに更新マークをつける
         if( m_code == HTTP_OK || m_code == HTTP_PARTIAL_CONTENT ){
 
             show_updateicon( true );
 
+            // このスレが所属する板を更新可能状態にしてお気に入りやスレ一覧のタブのアイコンに更新マークを表示
+            DBTREE::board_show_updateicon( m_url, true );
+
+            // スレ一覧の ! 行のアイコンを更新マークにする
             CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
         }
 
@@ -1159,6 +1190,9 @@ void ArticleBase::slot_load_finished()
         std::cout << "check_update done\n";
 #endif
 
+        // 更新チェック時間を保存
+        save_info( true );
+
         // 次のスレを更新チェック
         CORE::get_checkupdate_manager()->pop_front();
 
@@ -1293,6 +1327,7 @@ void ArticleBase::slot_load_finished()
 
             if( m_number < m_number_load ) m_number = m_number_load;
 
+            m_status |= STATUS_UPDATED;
             show_updateicon( false );
 
             // 情報ファイルのパスをセット
@@ -1328,7 +1363,7 @@ void ArticleBase::slot_load_finished()
 
 
 //
-// 更新アイコン表示
+// お気に入りのアイコンとスレビューのタブのアイコンに更新マークを表示
 //
 // update == true の時に表示。falseなら戻す
 //
@@ -1341,31 +1376,40 @@ void ArticleBase::show_updateicon( const bool update )
 
     struct timeval tv;
     struct timezone tz;
-    if( gettimeofday( &tv, &tz ) != 0 ) m_check_update_time = tv;
+    if( gettimeofday( &tv, &tz ) == 0 ) m_check_update_time = tv;
 
     if( update ){
 
+        if( ! ( m_status & STATUS_UPDATE ) ){
+
 #ifdef _DEBUG
-        std::cout << "toggle_icon on\n";
+            std::cout << "toggle_icon on\n";
 #endif
 
-        if( ! ( m_status & STATUS_UPDATE ) ) m_save_info = true;
-        m_status |= STATUS_UPDATE;
+            m_save_info = true;
+            m_status |= STATUS_UPDATE;
 
-        CORE::core_set_command( "toggle_article_icon", m_url);
-        CORE::core_set_command( "toggle_favorite_icon", m_url );
+            // スレビューのタブのアイコン表示を更新
+            CORE::core_set_command( "toggle_article_icon", m_url);
+
+            CORE::core_set_command( "toggle_favorite_articleicon", m_url );
+        }
     }
     else{
 
+        if( m_status & STATUS_UPDATE ){
+
 #ifdef _DEBUG
-        std::cout << "toggle_icon off\n";
+            std::cout << "toggle_icon off\n";
 #endif
 
-        if( m_status & STATUS_UPDATE ) m_save_info = true;
-        m_status &= ~STATUS_UPDATE;
+            m_save_info = true;
+            m_status &= ~STATUS_UPDATE;
 
-        // お気に入りのアイコン表示を戻す。スレタブのアイコンの方はArticleViewが戻す
-        CORE::core_set_command( "toggle_favorite_icon", m_url );
+            // お気に入りのアイコン表示を戻す
+            // スレビューのタブのアイコンはArticleViewがロード終了時に自動的に戻す
+            CORE::core_set_command( "toggle_favorite_articleicon", m_url );
+        }
     }
 }
 
@@ -1392,7 +1436,7 @@ void ArticleBase::delete_cache( const bool cache_only )
 
     m_number_load = m_number_seen = m_number_before_load = 0;
     m_cached = false;
-    m_status = STATUS_UNKNOWN;
+    reset_status();
     m_date_modified.clear();
     memset( &m_access_time, 0, sizeof( struct timeval ) );
     memset( &m_check_update_time, 0, sizeof( struct timeval ) );
@@ -1419,6 +1463,7 @@ void ArticleBase::delete_cache( const bool cache_only )
         m_vec_abone_res.clear();
         m_abone_transparent = false;
         m_abone_chain = false;
+        m_abone_age = false;
         m_read_info = false;
         m_save_info = false;
         m_bookmarked_thread = false;
@@ -1441,7 +1486,7 @@ void ArticleBase::delete_cache( const bool cache_only )
     CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
 
     // お気に入りのアイコン表示を戻す
-    CORE::core_set_command( "toggle_favorite_icon", m_url );
+    CORE::core_set_command( "toggle_favorite_articleicon", m_url );
 }
 
 
@@ -1456,15 +1501,15 @@ bool ArticleBase::save_dat( const std::string& path_to )
     if( is_loading() ) return false;
 
     std::string dir = MISC::get_dir( path_to );
-    if( dir.empty() ) dir = SESSION::dir_dat_save();
+    if( dir.empty() ) dir = SESSION::get_dir_dat();
 
     std::string name = MISC::get_filename( path_to );
-    if( name.empty() ) name = MISC::get_filename( m_url );    
+    if( name.empty() ) name = get_id();
 
     std::string save_to = CACHE::copy_file( NULL, CACHE::path_dat( m_url ), dir + name, CACHE::FILE_TYPE_DAT );
 
     if( ! save_to.empty() ){
-        SESSION::set_dir_dat_save( MISC::get_dir( save_to ) );
+        SESSION::set_dir_dat( MISC::get_dir( save_to ) );
         return true;
     }
 
@@ -1504,7 +1549,6 @@ void ArticleBase::read_info()
 
         std::list< std::string > lines = MISC::get_lines( str_info );
         std::list < std::string >::iterator it = lines.begin(), it2;
-        std::string option; // GET_INFOVALUE　で使用
 
         // subject
         GET_INFOVALUE( m_subject, "subject = " );
@@ -1570,7 +1614,7 @@ void ArticleBase::read_info()
         if( ! str_tmp.empty() ) m_write_fixmail = atoi( str_tmp.c_str() );
 
         // 状態
-        m_status = STATUS_UNKNOWN;
+        reset_status();
         GET_INFOVALUE( str_tmp, "status = " );
         if( ! str_tmp.empty() ) m_status = atoi( str_tmp.c_str() );
 
@@ -1650,6 +1694,21 @@ void ArticleBase::read_info()
                 else m_vec_posted[ number ] = false;
             }
         }
+
+        // ageあぼーん
+        m_abone_age = false;
+        GET_INFOVALUE( str_tmp, "aboneage = " );
+        if( ! str_tmp.empty() ) m_abone_age = atoi( str_tmp.c_str() );
+
+        // 最終更新チェック時間
+        GET_INFOVALUE( str_tmp, "checktime = " );
+        if( ! str_tmp.empty() ){
+            list_tmp = MISC::split_line( str_tmp );
+            if( list_tmp.size() == 2 ){
+                it_tmp = list_tmp.begin();
+                m_check_update_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
+            }
+        }
     }
 
     // キャッシュはあるけど情報ファイルが無い場合
@@ -1666,6 +1725,7 @@ void ArticleBase::read_info()
         CORE::core_set_command( "set_status","", "スレ情報更新中・・・しばらくお待ち下さい" );
         MISC::MSG( "updating " + m_url );
 
+        reset_status();
         set_subject( get_nodetree()->get_subject() );
         m_number_load = get_nodetree()->get_res_number();
 
@@ -1760,7 +1820,11 @@ void ArticleBase::save_info( const bool force )
 
     // 書き込み時間
     std::ostringstream ss_write;
-    ss_write << ( m_write_time.tv_sec >> 16 ) << " " << ( m_write_time.tv_sec & 0xffff ) << " " << m_write_time.tv_usec;
+    if( m_write_time.tv_sec ) ss_write << ( m_write_time.tv_sec >> 16 ) << " " << ( m_write_time.tv_sec & 0xffff ) << " " << m_write_time.tv_usec;
+
+    // 更新チェック時間
+    std::ostringstream ss_check;
+    if( m_check_update_time.tv_sec ) ss_check << ( m_check_update_time.tv_sec >> 16 ) << " " << ( m_check_update_time.tv_sec & 0xffff );
 
     // あぼーん情報
     std::string str_abone_id = MISC::listtostr( m_list_abone_id );
@@ -1809,6 +1873,8 @@ void ArticleBase::save_info( const bool force )
          << "aboneres = " << ss_abone_res.str() << std::endl
          << "bkmark_thread = " << m_bookmarked_thread << std::endl
          << "posted = " << ss_posted.str() << std::endl
+         << "aboneage = " << m_abone_age << std::endl
+         << "checktime = " << ss_check.str() << std::endl
     ;
 
 #ifdef _DEBUG
