@@ -53,7 +53,7 @@ namespace DBTREE
 
         virtual bool is_valid( const std::string& filename );
 
-        virtual ArticleBase* append_article( const std::string& id, bool cached );
+        virtual ArticleBase* append_article( const std::string& datbase, const std::string& id, const bool cached );
         virtual void parse_subject( const char* str_subject_txt );
 
         virtual void load_rule_setting();
