@@ -1,10 +1,12 @@
 // ライセンス: GPL2
 
 //#define _DEBUG
+//#define _TEST_CACHE
 #include "jddebug.h"
 
 #include "boardbase.h"
 #include "articlebase.h"
+#include "articlehash.h"
 #include "interface.h"
 
 #include "skeleton/msgdiag.h"
@@ -27,6 +29,13 @@
 #include <sstream>
 #include <cstring>
 
+
+#ifdef _TEST_CACHE
+int cache_hit_art = 0;
+int cache_nohit_art = 0;
+#endif
+
+
 enum
 {
     SIZE_OF_RAWDATA = 2 * 1024 * 1024
@@ -37,6 +46,7 @@ using namespace DBTREE;
 
 BoardBase::BoardBase( const std::string& root, const std::string& path_board, const std::string& name )
     : SKELETON::Loadable()
+    , m_status( STATUS_UNKNOWN )
     , m_list_subject_created( false )
     , m_root( root )
     , m_path_board( path_board )
@@ -48,6 +58,7 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_rawdata( 0 )
     , m_read_info( 0 )
     , m_append_articles( false )
+    , m_get_article( NULL )
     , m_article_null( 0 )
 {
     clear();
@@ -55,6 +66,8 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
 
     memset( &m_write_time, 0, sizeof( struct timeval ) );
 
+    m_hash_article = new ArticleHash();
+
     // 板情報はクラスが作られた時点ではまだ読まない
     // BoardBase::read_info() の説明を見ること
 }
@@ -66,15 +79,26 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
 BoardBase::~BoardBase()
 {
 #ifdef _DEBUG
-    if( m_list_article.size() ) std::cout << "BoardBase::~BoardBase : " << url_boardbase() << std::endl;
+    if( m_hash_article->size() ) std::cout << "BoardBase::~BoardBase : " << url_boardbase() << std::endl;
 #endif
 
     clear();
 
-    std::list< ArticleBase* >::iterator it;
-    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ) delete ( *it );
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) delete ( *it );
 
     if( m_article_null ) delete m_article_null;
+
+    delete m_hash_article;
+
+#ifdef _TEST_CACHE
+    if( m_hash_article->size() ){
+        std::cout << "article cache\n"
+                  << "hit = " << cache_hit_art << std::endl
+                  << "nohit = " << cache_nohit_art << std::endl
+                  << "hit/total*100 = " << (double)(cache_hit_art)/(cache_hit_art+cache_nohit_art)*100. << std::endl;
+    }
+#endif    
 }
 
 
@@ -278,7 +302,7 @@ void BoardBase::send_update_board()
 //
 // 新しくArticleBaseクラスを追加してそのポインタを返す
 //
-ArticleBase* BoardBase::append_article( const std::string& id, bool cached )
+ArticleBase* BoardBase::append_article( const std::string& datbase, const std::string& id, const bool cached )
 {
     // ベースクラスでは何もしない
     return get_article_null();
@@ -342,10 +366,10 @@ void BoardBase::clear_all_post_history()
 {
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
-    if( m_list_article.size() == 0 ) return;
+    if( m_hash_article->size() == 0 ) return;
 
-    std::list< ArticleBase* >::iterator it;
-    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ) ( *it )->clear_post_history();
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->clear_post_history();
 }
 
 
@@ -397,8 +421,9 @@ void BoardBase::update_url( const std::string& root, const std::string& path_boa
     set_date_modified( std::string() );
 
     // 配下の ArticleBase にも知らせてあげる
-    std::list< ArticleBase* >::iterator it;
-    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ) ( *it )->update_datbase( url_datbase() );
+    const std::string datbase = url_datbase();
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->update_datbase( datbase );
 }
 
 
@@ -502,9 +527,11 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
         return std::string();
     }        
 
+    const std::string datbase = url_datbase();
+
 #ifdef _DEBUG
     std::cout << "BoardBase::url_dat result : " << url << " ->\n";
-    std::cout << "datbase = " << url_datbase() << " id = " << id << " from " << num_from << " to " << num_to
+    std::cout << "datbase = " << datbase << " id = " << id << " from " << num_from << " to " << num_to
               << " num = " << num_str << std::endl;
 #endif
 
@@ -514,10 +541,10 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
 #ifdef _DEBUG
         std::cout << "org_host : " << MISC::get_hostname( url ) << std::endl;
 #endif
-        get_article_create( id )->set_org_host( MISC::get_hostname( url ) );
+        get_article_create( datbase, id )->set_org_host( MISC::get_hostname( url ) );
     }
 
-    return url_datbase() + id;
+    return datbase + id;
 }
 
 
@@ -687,25 +714,19 @@ const std::string BoardBase::url_subbbscgibase()
 
 
 //
-// article のIDから　m_list_article　から　article のポインタを検索して返すだけ
+// article のID を渡してハッシュから article のポインタを検索して返すだけ
 //
 // 無ければNULLクラスを返す
 //
-ArticleBase* BoardBase::get_article( const std::string& id )
+ArticleBase* BoardBase::get_article( const std::string& datbase, const std::string& id )
 {
     if( id.empty() ) return get_article_null();
 
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
 
-    // 線形リストなので遅い
-    // TODO : ハッシュにする
-    std::list< ArticleBase* >::iterator it;
-    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
-
-        ArticleBase* art = *( it );
-        if( art->get_id() == id ) return art;
-    }
+    ArticleBase* art = m_hash_article->find( datbase, id );
+    if( art ) return art;
 
     return get_article_null();
 }
@@ -713,45 +734,36 @@ ArticleBase* BoardBase::get_article( const std::string& id )
 
 
 //
-// articleの IDを渡して m_list_article　から article のポインタを検索して返す
+// articleの IDを渡して ハッシュから article のポインタを検索して返す
 //
 // ポインタがあった場合は情報ファイルを読み込む
 // さらにデータベースにArticleBaseクラスが登録されてない場合はクラスを作成して登録する
 //
-ArticleBase* BoardBase::get_article_create( const std::string& id )
+ArticleBase* BoardBase::get_article_create( const std::string& datbase, const std::string& id )
 {
 #ifdef _DEBUG
     std::cout << "BoardBase::get_article_create id = " << id << std::endl;
 #endif
 
-    ArticleBase* art = get_article( id );
+    ArticleBase* art = get_article( datbase, id );
 
+    // データベースに無いので新規登録
     // get_article() の中で append_all_article_in_cache() を
-    // 呼び出しているので、スレがキャッシュ内にある場合は !art->empty() になるのに注意
-    if( ! art->empty() ){
-
-#ifdef _DEBUG
-        std::cout << "found id = " << art->get_id() << std::endl;
-#endif
-        // ポインタを返す前にスレッドの情報ファイルを読み込み
-        art->read_info();
-    }
-    else{
-
-        // データベースに無いので新規登録
-        //
-        // なおget_article()でキャッシュにある
-        // スレは全てDBに登録されているので DBに無いということはキャッシュにも無いということ。
-        // よって append_article()に  cached = false　をパラメータとして渡す
+    // 呼び出しているので、スレがキャッシュ内にない場合 art->empty() == TRUE になる
+    if( art->empty() ){
 
 #ifdef _DEBUG        
         std::cout << "BoardBase::get_article_create : append_article id =  " << id << std::endl;
 #endif
-        art = append_article( id,
+        art = append_article( datbase, id,
                               false // キャッシュ無し
             );
+
+        assert( art );
     }
 
+    if( art->is_cached() ) art->read_info();
+
     return art;
 }
 
@@ -759,7 +771,7 @@ ArticleBase* BoardBase::get_article_create( const std::string& id )
 
 
 //
-// article の URL を渡して　m_list_article　から　article のポインタを検索して返す
+// article の URL を渡してハッシュから　article のポインタを検索して返す
 //
 // さらにデータベースにArticleBaseクラスが登録されてない場合はクラスを作成して登録する
 //
@@ -768,7 +780,14 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string& url )
     if( empty() ) return get_article_null();
 
     // キャッシュ
-    if( url == m_get_article_url ) return m_get_article;
+    if( url == m_get_article_url ){
+
+#ifdef _TEST_CACHE
+        ++cache_hit_art;
+#endif
+        return m_get_article;
+    }
+
     m_get_article_url = url;
     m_get_article = get_article_null();
 
@@ -776,37 +795,30 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string& url )
     std::cout << "BoardBase::get_article_fromURL url = " << url << std::endl;
 #endif
 
-    // urlをdat型に変換してからID取得
+    // dat型のURLにしてdatbaseとidを取得
     int num_from, num_to;
     std::string num_str;
     const std::string urldat = url_dat( url, num_from, num_to, num_str );
+    if( urldat.empty() ) return m_get_article;
 
-    // 板がDBに登録されてないので NULL クラスを返す
-    if( urldat.empty() ){
-
-#ifdef _DEBUG
-        std::cout << "could not convert url to daturl\nreturn Article_Null\n";
-#endif
-        return m_get_article;
-    }
-
-    // id を抜き出して article クラスのポインタ取得
-    std::string id = urldat.substr( url_datbase().length() );
-
-#ifdef _DEBUG
-    std::cout << "urldat = " << urldat << std::endl
-              << "url_datbase = " << url_datbase() << std::endl
-              << "id = " << id << std::endl;
-    if( id.empty() ) std::cout << "return Article_Null\n";
-#endif
-
+    const std::string datbase = url_datbase();
+    const std::string id = urldat.substr( datbase.length() );
     if( id.empty() ) return m_get_article;
 
+#ifdef _DEBUG
+    std::cout << "datbase = " << datbase << std::endl
+              << "id = " << id << std::endl;
+#endif
+
+#ifdef _TEST_CACHE
+    ++cache_nohit_art;
+#endif
+
     // get_article_create() 経由で ArticleBase::read_info() から get_article_fromURL()が
     // 再帰呼び出しされることもあるので m_get_article_url を空にしておく
     m_get_article_url = std::string(); 
 
-    m_get_article = get_article_create( id );
+    m_get_article = get_article_create( datbase, id );
     m_get_article_url = url;
     return m_get_article;
 }
@@ -817,12 +829,14 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string& url )
 // subject.txt ダウンロード
 //
 // url_update_view : CORE::core_set_command( "update_board" ) を送信するビューのアドレス
+// read_from_cache : まだスレ一覧を開いていないときにキャッシュのsubject.txtを読み込む
 //
-void BoardBase::download_subject( const std::string& url_update_view )
+void BoardBase::download_subject( const std::string& url_update_view, const bool read_from_cache )
 {
 #ifdef _DEBUG
     std::cout << "BoardBase::download_subject " << url_subject() << std::endl
               << "url_update_view = " << url_update_view << std::endl
+              << "read_from_cache = " << read_from_cache << std::endl
               << "empty = " << empty() << std::endl
               << "loading = " << is_loading() << std::endl
               << "views = " << m_url_update_views.size() << std::endl;
@@ -830,24 +844,28 @@ void BoardBase::download_subject( const std::string& url_update_view )
 
     // ダウンロード中に他のビューから再びダウンロード依頼が来たら
     // ダウンロード終了時にまとめてビューにupdateコマンドを送る
-    m_url_update_views.push_back( url_update_view );
+    if( ! url_update_view.empty() ) m_url_update_views.push_back( url_update_view );
     if( m_url_update_views.size() >= 2 ) return;
 
     if( empty() ) return;
     if( is_loading() ) return;
+    if( read_from_cache && m_list_subject_created ) return;
 
     clear();
     m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
     m_read_url_boardbase = false;
-    m_is_online = SESSION::is_online();
+
+    if( read_from_cache ) m_is_online = false;
+    else m_is_online = SESSION::is_online();
 
     // オフライン
     if( ! m_is_online  ){
 
         set_str_code( "" );
 
-        // ディスパッチャ経由で receive_finish() を呼び出す
-        finish();
+        if( read_from_cache ) receive_finish();
+        else finish(); // ディスパッチャ経由で receive_finish() を呼び出す
+
         return;
     }
 
@@ -903,6 +921,8 @@ void BoardBase::receive_finish()
     if( m_is_online ) download_rule_setting();
 
     m_list_subject.clear();
+    m_list_abone_thread_remove.clear();
+    m_status &= ~STATUS_UPDATED;
 
     bool read_from_cache = false;
     std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
@@ -1042,20 +1062,22 @@ void BoardBase::receive_finish()
     // データベース更新
     // subject.txtを解析して現行スレだけsubjectリスト(m_list_subject)に加える
 
-    std::list< ArticleBase* >::iterator it;
-
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
 
     // 一度全てのarticleをdat落ち状態にして subject.txt に
     // 含まれているものだけ parse_subject()の中で通常状態にする
     // オフラインの場合は状態を変えない
-    if( m_is_online ) for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
+    if( m_is_online ){
 
-        int status = ( *it )->get_status();
-        status &= ~STATUS_NORMAL;
-        status |= STATUS_OLD;
-        ( *it )->set_status( status );
+        ArticleHashIterator it = m_hash_article->begin();
+        for( ; it != m_hash_article->end(); ++it ){
+
+            int status = ( *it )->get_status();
+            status &= ~STATUS_NORMAL;
+            status |= STATUS_OLD;
+            ( *it )->set_status( status );
+        }
     }
 
     // subject.txtをパースしながらデータベース更新
@@ -1068,12 +1090,29 @@ void BoardBase::receive_finish()
         std::cout << "list_subject was updated\n";
 #endif
 
+        if( m_is_online ){
+
+            // 既読スレに更新があったかチェック
+            std::list< ArticleBase* >::iterator it_art;
+            for( it_art = m_list_subject.begin(); it_art != m_list_subject.end(); ++it_art ){
+
+                if( ( *it_art )->is_cached() && ( *it_art )->get_number() > ( *it_art )->get_number_load() ){
+
+                    m_status |= STATUS_UPDATED;
+                    break;
+                }
+            }
+
+            show_updateicon( false );
+        }
+
         // DAT落ちなどでsubject.txtに無いスレもsubjectリストに加える
         // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
         // 取得する必要がある
         if( CONFIG::get_show_oldarticle() ){
 
-            for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
+            ArticleHashIterator it = m_hash_article->begin();
+            for( ; it != m_hash_article->end(); ++it ){
 
                 if( ( *it )->is_cached()
                     && ( ( *it )->get_status() & STATUS_OLD )
@@ -1111,7 +1150,7 @@ void BoardBase::receive_finish()
 #endif
         }
 
-        // オンライン、かつcodeが200なら情報を保存して subject.txt をキャッシュに保存
+        // オンライン、かつcodeが200なら情報を更新・保存して subject.txt をキャッシュに保存
         if( m_is_online && get_code() == HTTP_OK ){
 
             m_last_access_time = time( NULL );
@@ -1140,7 +1179,8 @@ void BoardBase::receive_finish()
         }
 
         m_list_subject_created = true;
-    }
+
+    } //  if( ! m_list_subject.empty() )
 
     // list_subject が更新されなかった
     else{
@@ -1175,15 +1215,9 @@ bool BoardBase::start_checkking_if_board_moved()
     std::cout << "BoardBase::start_checkking_if_board_moved " << url_boardbase() << std::endl;
 #endif
 
-    JDLIB::LOADERDATA data;    
+    JDLIB::LOADERDATA data;
+    data.init_for_data();
     data.url = url_boardbase();
-    data.agent = CONFIG::get_agent_for_data();
-    if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
-    else data.host_proxy = std::string();
-    data.port_proxy = CONFIG::get_proxy_port_for_data();
-    data.basicauth_proxy = CONFIG::get_proxy_basicauth_for_data();
-    data.size_buf = CONFIG::get_loader_bufsize();
-    data.timeout = CONFIG::get_loader_timeout_img();
 
     if( start_load( data ) ){
         m_read_url_boardbase = true;
@@ -1232,6 +1266,8 @@ void BoardBase::append_all_article_in_cache()
     if( m_append_articles ) return;
     m_append_articles = true;
 
+    const std::string datbase = url_datbase();
+
 #ifdef _DEBUG
     std::cout << "BoardBase::append_all_article_in_cache\n";
 #endif
@@ -1248,7 +1284,7 @@ void BoardBase::append_all_article_in_cache()
         // キャッシュあり( cached = true ) 指定でDBに登録
         // キャッシュに無いスレはsubject.txtを読み込んだ時に
         // 派生クラスのparse_subject()で登録する。
-        append_article( ( *it ),
+        append_article( datbase, ( *it ),
                         true  // キャッシュあり
             );
     }
@@ -1261,8 +1297,8 @@ void BoardBase::append_all_article_in_cache()
 //
 void BoardBase::update_abone_all_article()
 {
-    std::list< ArticleBase* >::iterator it = m_list_article.begin();
-    for( ; it != m_list_article.end(); ++it ) ( *it )->update_abone();
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->update_abone();
 }
 
 
@@ -1298,7 +1334,13 @@ const bool BoardBase::is_abone_thread( ArticleBase* article )
     if( check_thread ){
         std::list< std::string >::iterator it = m_list_abone_thread.begin();
         for( ; it != m_list_abone_thread.end(); ++it ){
-            if( article->get_subject() == (*it) ) return true;
+            if( MISC::remove_space( article->get_subject() ) == MISC::remove_space(*it) ){
+
+                // 対象スレがDat落ちした場合はあぼーんしなかったスレ名をリストから消去する
+                // remove_old_abone_thread() も参照
+                m_list_abone_thread_remove.push_back( *it );
+                return true;
+            }
         }
     }
 
@@ -1339,9 +1381,35 @@ const bool BoardBase::is_abone_thread( ArticleBase* article )
 
 
 //
-// スレあぼーん状態の更新
+// subject.txtのロード後にdat落ちしたスレッドをスレあぼーんのリストから取り除く
 //
-// force = true なら強制更新
+// is_abone_thread() も参照せよ
+//
+void BoardBase::remove_old_abone_thread()
+{
+    if( m_list_abone_thread.empty() ) return;
+    if( m_list_abone_thread.size() == m_list_abone_thread_remove.size() ) return;
+
+#ifdef _DEBUG
+    std::cout << "BoardBase::remove_old_abone_thread\n";
+    std::list< std::string >::const_iterator it = m_list_abone_thread.begin();
+    for( ; it != m_list_abone_thread.end(); ++it ) std::cout << ( *it ) << std::endl;
+    std::cout << "->\n";
+    std::list< std::string >::const_iterator it2 = m_list_abone_thread_remove.begin();
+    for( ; it2 != m_list_abone_thread_remove.end(); ++it2 ) std::cout << ( *it2 ) << std::endl;
+#endif
+
+    SKELETON::MsgDiag mdiag( NULL, "NGスレタイトルに登録したスレがdat落ちしました。\n\nNGスレタイトルから除外しますか？",
+                             false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+    mdiag.set_default_response( Gtk::RESPONSE_YES );
+    if( mdiag.run() == Gtk::RESPONSE_YES ) m_list_abone_thread = m_list_abone_thread_remove;
+}
+
+
+//
+// スレあぼーん情報を更新した時に対応するスレ一覧の表示を更新する
+//
+// CONFIG::set_abone_number_thread() などでグローバル設定をした後などに呼び出す
 //
 void BoardBase::update_abone_thread()
 {
@@ -1349,7 +1417,6 @@ void BoardBase::update_abone_thread()
     std::cout << "BoardBase::update_abone_thread\n";
 #endif
 
-    // Root::update_abone_all_board() であぼーん状態を全更新するときなど
     // まだスレ一覧にスレを表示していないBoardBaseクラスは更新しない
     if( ! m_list_subject_created ) return;
 
@@ -1357,7 +1424,7 @@ void BoardBase::update_abone_thread()
     const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    download_subject( url_subject() );
+    download_subject( url_subject(), false );
 
     SESSION::set_online( online );
 }
@@ -1365,9 +1432,12 @@ void BoardBase::update_abone_thread()
 
 
 //
-// あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
+// 板レベルでのあぼーん状態のリセット(情報セットとスレビューの表示更新を同時におこなう)
 //
-void BoardBase::reset_abone( std::list< std::string >& ids, std::list< std::string >& names, std::list< std::string >& words, std::list< std::string >& regexs )
+void BoardBase::reset_abone_board( const std::list< std::string >& ids,
+                                   const std::list< std::string >& names,
+                                   const std::list< std::string >& words,
+                                   const std::list< std::string >& regexs )
 {
     if( empty() ) return;
 
@@ -1390,8 +1460,8 @@ void BoardBase::reset_abone( std::list< std::string >& ids, std::list< std::stri
 }
 
 
-// あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
-void BoardBase::add_abone_id( const std::string& id )
+// 板レベルでのあぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう。スレビューの表示更新も同時におこなう)
+void BoardBase::add_abone_id_board( const std::string& id )
 {
     if( empty() ) return;
     if( id.empty() ) return;
@@ -1404,7 +1474,7 @@ void BoardBase::add_abone_id( const std::string& id )
     CORE::core_set_command( "relayout_all_article" );
 }
 
-void BoardBase::add_abone_name( const std::string& name )
+void BoardBase::add_abone_name_board( const std::string& name )
 {
     if( empty() ) return;
     if( name.empty() ) return;
@@ -1415,7 +1485,7 @@ void BoardBase::add_abone_name( const std::string& name )
     CORE::core_set_command( "relayout_all_article" );
 }
 
-void BoardBase::add_abone_word( const std::string& word )
+void BoardBase::add_abone_word_board( const std::string& word )
 {
     if( empty() ) return;
     if( word.empty() ) return;
@@ -1428,11 +1498,13 @@ void BoardBase::add_abone_word( const std::string& word )
 
 
 //
-// あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
+// スレあぼーん状態のリセット(情報セットとスレ一覧の表示更新を同時におこなう)
 //
-void BoardBase::reset_abone_thread( std::list< std::string >& threads,
-                                    std::list< std::string >& words, std::list< std::string >& regexs,
-                                    const int number, const int hour )
+void BoardBase::reset_abone_thread( const std::list< std::string >& threads,
+                                    const std::list< std::string >& words,
+                                    const std::list< std::string >& regexs,
+                                    const int number,
+                                    const int hour )
 {
     if( empty() ) return;
 
@@ -1516,15 +1588,15 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
 
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
-    if( m_list_article.size() == 0 ) return list_out;
+    if( m_hash_article->size() == 0 ) return list_out;
 
     std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
     std::list< std::string > list_query = MISC::split_line( query_local );
 
     std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
 
-    std::list< ArticleBase* >::iterator it;
-    for( it = m_list_article.begin(); it != m_list_article.end(); ++it ){
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ){
 
         ArticleBase* article = ( *it );
         if( ! article->is_cached() ) continue;
@@ -1566,6 +1638,50 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
 }
 
 
+// datファイルのインポート
+// 成功したらdat型のurlを返す
+const std::string BoardBase::import_dat( const std::string& filename )
+{
+    if( empty() ) return std::string();
+    if( CACHE::file_exists( filename ) != CACHE::EXIST_FILE ){
+        SKELETON::MsgDiag mdiag( NULL, "datファイルが存在しません" );
+        mdiag.run();
+        return std::string();
+    }
+
+    const std::string dir = MISC::get_dir( filename );
+    const std::string id = MISC::get_filename( filename );
+    if( id.empty() || ! is_valid( id ) ){
+        SKELETON::MsgDiag mdiag( NULL, "ファイル名が正しくありません" );
+        mdiag.run();
+        return std::string();
+    }
+
+    const std::string file_to = CACHE::path_board_root_fast( url_boardbase() ) + id;
+
+#ifdef _DEBUG
+    std::cout << "BoardBase::import_dat cp " << filename
+              << " " << file_to << std::endl;
+#endif
+
+    const std::string datbase = url_datbase();
+    ArticleBase* art = get_article_create( datbase, id );
+    if( ! art->is_cached() ){
+
+        CACHE::jdcopy( filename, file_to );
+        if( CACHE::file_exists( file_to ) == CACHE::EXIST_FILE ){
+            art->set_cached( true );
+            art->read_info();
+        }
+        else{
+            SKELETON::MsgDiag mdiag( NULL, "datファイルのコピーに失敗しました" );
+            mdiag.run();
+            return std::string();
+        }
+    }
+
+    return art->get_url();
+}
 
 
 //
@@ -1657,6 +1773,9 @@ void BoardBase::read_board_info()
     // 最終アクセス時刻
     m_last_access_time = cf.get_option( "last_access_time", 0 );
 
+    // ステータス
+    m_status = cf.get_option( "status", STATUS_UNKNOWN );
+
 #ifdef _DEBUG
     std::cout << "modified = " << get_date_modified() << std::endl;
 #endif
@@ -1743,6 +1862,7 @@ void BoardBase::save_jdboard_info()
          << "samba_sec = " << m_samba_sec << std::endl
          << "live_sec = " << m_live_sec << std::endl
          << "last_access_time = " << m_last_access_time << std::endl
+         << "status = " << m_status
     ;
 
     CACHE::save_rawdata( path_info, sstr.str() );
@@ -1843,3 +1963,110 @@ void BoardBase::save_board_info()
 
     CACHE::save_rawdata( path_info, str_out );
 }
+
+
+// 更新可能状態にしてお気に入りやスレ一覧のタブのアイコンに更新マークを表示
+// update == true の時に表示。falseなら戻す
+void BoardBase::show_updateicon( const bool update )
+{
+#ifdef _DEBUG
+    std::cout << "BoardBase::show_updateicon url = " << url_boardbase()
+              << " update = " << update << " status = " << ( m_status & STATUS_UPDATE ) << std::endl;
+#endif
+
+    if( update ){
+
+        if( ! ( m_status & STATUS_UPDATE ) ){
+
+#ifdef _DEBUG
+            std::cout << "toggle_icon on\n";
+#endif
+
+            m_status |= STATUS_UPDATE;
+
+            // スレ一覧のタブのアイコン表示を更新
+            CORE::core_set_command( "toggle_board_icon", url_subject() );
+
+            // お気に入りのアイコン表示を更新
+            CORE::core_set_command( "toggle_favorite_boardicon", url_datbase() );
+
+            save_info();
+        }
+    }
+    else{
+
+        if( m_status & STATUS_UPDATE ){
+
+#ifdef _DEBUG
+            std::cout << "toggle_icon off\n";
+#endif
+
+            m_status &= ~STATUS_UPDATE;
+
+            // お気に入りのアイコン表示を戻す
+            // スレ一覧のタブのアイコンはBoardViewがロード終了時に自動的に戻す
+            CORE::core_set_command( "toggle_favorite_boardicon", url_subject() );
+
+            save_info();
+        }
+    }
+}
+
+
+// 板の更新チェック時に、更新チェックを行うスレのアドレスのリスト
+// キャッシュが存在し、かつdat落ちしていないで新着数が0のスレを速度の順でソートして返す
+const std::list< std::string > BoardBase::get_check_update_articles()
+{
+    std::list< std::string > list_url;
+
+    if( empty() ) return list_url;
+    if( is_loading() ) return list_url;
+    if( m_status & STATUS_UPDATE ) return list_url;
+    if( ! m_list_subject_created ) download_subject( std::string(), true );
+    if( ! m_list_subject_created ) return list_url;
+
+#ifdef _DEBUG
+    std::cout << "BoardBase::get_check_update_articles url = " << url_boardbase() << std::endl;
+#endif
+
+    std::list< int > list_speed;
+
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ){
+
+        if( ( *it )->is_cached()
+            && ( *it )->get_number()
+            && ! ( ( *it )->get_status() & STATUS_UPDATE )
+            && ! ( ( *it )->get_status() & STATUS_OLD )
+            && ( *it )->get_number() == ( *it )->get_number_load()
+            ){
+
+            const std::string& url = ( *it )->get_url();
+            const int speed = ( *it )->get_speed();
+
+#ifdef _DEBUG
+            std::cout << "added " << url
+                      << " number = " << ( *it )->get_number()
+                      << " load = " << ( *it )->get_number_load()
+                      << " speed = " << speed
+                      << " " << ( *it )->get_subject() << std::endl;
+#endif
+
+            // 挿入ソート
+            std::list< std::string >::iterator it_url = list_url.begin();
+            std::list< int >::iterator it_speed = list_speed.begin();
+            for( ; it_url != list_url.end(); ++it_url, ++it_speed ) if( ( *it_speed ) < speed ) break;
+            list_url.insert( it_url, url );
+            list_speed.insert( it_speed, speed );
+        }
+    }
+
+#ifdef _DEBUG
+    std::cout << "result of insert sorting\n";
+    std::list< std::string >::const_iterator it_url = list_url.begin();
+    std::list< int >::const_iterator it_speed = list_speed.begin();
+    for( ; it_url != list_url.end(); ++it_url, ++it_speed ) std::cout << ( *it_speed ) << " / " << ( *it_url ) << std::endl;
+#endif 
+
+    return list_url;
+}
