@@ -29,6 +29,11 @@ namespace DBTREE
         LINK_NUM
     };
 
+    enum
+    {
+        RESUME_CHKSIZE = 64
+    };
+
     //ノードツリーのベースクラス
     class NodeTreeBase : public SKELETON::Loadable
     {
@@ -43,8 +48,15 @@ namespace DBTREE
         // コード変換前の生データのサイズ ( byte )
         size_t m_lng_dat; 
 
-        // true ならレジューム読み込み
-        bool m_resume;
+        // レジュームのモード
+        int m_resume;
+
+        // レジューム時のチェック用
+        // 生データの先頭から RESUME_CHKSIZE バイト分を入れる
+        char m_resume_head[ RESUME_CHKSIZE ];
+
+        // レジューム中にスキップした生データサイズ
+        size_t m_resume_lng;
 
         // 現在処理中のヘッダ番号( つまりロード中でないなら総レス数になる )
         int m_id_header; 
@@ -80,6 +92,7 @@ namespace DBTREE
         std::vector< char > m_vec_abone_res; // レスあぼーん情報
         bool m_abone_transparent; // 透明あぼーん
         bool m_abone_chain; // 連鎖あぼーん
+        bool m_abone_age; // age ているレスはあぼーん
 
         // 自分が書き込んだレスか
         std::vector< char > m_vec_posted;
@@ -94,6 +107,7 @@ namespace DBTREE
         char* m_buffer_write; // 書き込みチェック用バッファ
         bool m_check_update; // HEADによる更新チェックのみ
         bool m_check_write; // 自分の書き込みかチェックする
+        bool m_loading_newthread; // 新スレ読み込み中
         
         // キャッシュ保存用ファイルハンドラ
         FILE *m_fout;
@@ -106,14 +120,14 @@ namespace DBTREE
 
       protected:
 
-        void set_resume( bool resume ) { m_resume = resume; }
-        void set_broken( bool broken ) { m_broken = broken; }
+        void set_resume( const bool resume );
+        void set_broken( const bool broken ) { m_broken = broken; }
         const int id_header() const { return m_id_header; }
         void set_ext_err( const std::string& ext_err ){ m_ext_err = ext_err; }
 
       public:
 
-        NodeTreeBase( const std::string url, const std::string& date_modified );
+        NodeTreeBase( const std::string& url, const std::string& date_modified );
         virtual ~NodeTreeBase();
 
         bool empty();
@@ -197,16 +211,18 @@ namespace DBTREE
 
         // ロード開始
         // check_update : HEADによる更新チェックのみ
-        void download_dat( const bool check_update );
+        virtual void download_dat( const bool check_update );
 
         // あぼーんしているか
         bool get_abone( int number );
 
         // あぼーん情報を親クラスのarticlebaseからコピーする
-        void copy_abone_info( std::list< std::string >& list_abone_id, std::list< std::string >& list_abone_name,
-                              std::list< std::string >& list_abone_word, std::list< std::string >& list_abone_regex,
+        void copy_abone_info( const std::list< std::string >& list_abone_id,
+                              const std::list< std::string >& list_abone_name,
+                              const std::list< std::string >& list_abone_word,
+                              const std::list< std::string >& list_abone_regex,
                               const std::vector< char >& vec_abone_res,
-                              const bool abone_transparent, const bool abone_chain );
+                              const bool abone_transparent, const bool abone_chain, const bool abone_age );
 
         // 全レスのあぼーん状態の更新
         // 発言数や参照数も更新する
@@ -219,6 +235,9 @@ namespace DBTREE
         // 自分の書き込みにレスしたか
         const bool is_refer_posted( const int number );
 
+        // 書き込み履歴のリセット
+        void clear_post_history();
+
       protected:
 
         virtual void clear();
@@ -243,47 +262,60 @@ namespace DBTREE
 
       private:
 
-        NODE* createNode();
-        NODE* create_header_node();
-        NODE* create_block_node();
-        NODE* createIDNumNode();
-        NODE* createBrNode();
-        NODE* createHrNode();
-        NODE* createSpNode( const int& type );
-        NODE* createHTabNode();
-        NODE* create_linknode( const char* text, int n, const char* link, int n_link, int color_text, bool bold );
-        NODE* create_ancnode( const char* text, int n, const char* link, int n_link, int color_text, bool bold,
-                              ANCINFO* ancinfo, int lng_ancinfo );
-        NODE* create_imgnode( const char* text, int n, const char* link, int n_link, int color_text, bool bold );
-        NODE* createTextNode( const char* text, int color_text, bool bold = false );
-        NODE* createTextNodeN( const char* text, int n, int color_text, bool bold = false );
+        NODE* create_node();
+        NODE* create_node_header();
+        NODE* create_node_block();
+        NODE* create_node_idnum();
+        NODE* create_node_br();
+        NODE* create_node_hr();
+        NODE* create_node_space( const int type );
+        NODE* create_node_htab();
+        NODE* create_node_link( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold );
+        NODE* create_node_anc( const char* text, const int n, const char* link, const int n_link,
+                               const int color_text, const bool bold,
+                               const ANCINFO* ancinfo, const int lng_ancinfo );
+        NODE* create_node_sssp( const char* link, const int n_link );
+        NODE* create_node_img( const char* text, const int n, const char* link, const int n_link, const int color_text, const bool bold );
+        NODE* create_node_text( const char* text, const int color_text, const bool bold = false );
+        NODE* create_node_ntext( const char* text, const int n, const int color_text, const bool bold = false );
 
         // 以下、構文解析用関数
         void add_raw_lines( char* rawines, size_t size );
         const char* add_one_dat_line( const char* datline );
 
-        void parseName( NODE* header, const char* str, int lng, int color_name );
-        void parseMail( NODE* header, const char* str, int lng );
-        void parse_date_id( NODE* header, const char* str, int lng );
-        void parse_html( const char* str, int lng, int color_text, bool digitlink = false, bool bold = false, bool ahref = false );
+        void parse_name( NODE* header, const char* str, const int lng, const int color_name );
+        void parse_mail( NODE* header, const char* str, const int lng );
+        void parse_date_id( NODE* header, const char* str, const int lng );
+
+        // HTMLパーサ
+        // digitlink : true の時は先頭に数字が現れたらアンカーにする( parse_name() などで使う )
+        //             false なら数字の前に >> がついてるときだけアンカーにする
+        // bold : ボールド表示
+        // ahref : <a href=～></a> からリンクノードを作成する
+        // enable_sssp : true の時はssspアイコンを有効にする( ssspは 1 スレ 1 つだけアイコン表示)
+        void parse_html( const char* str, const int lng, const int color_text,
+                         bool digitlink, const bool bold, const bool ahref, const bool sssp );
+
+        // 書き込みログ比較用文字列作成
+        // m_buffer_write に作成した文字列をセットする
         void parse_write( const char* str, const int lng, const int max_lng_write );
-        void parseBr( );
 
         bool check_anchor( int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo );
-        bool check_link( const char* str_in, int lng_in, int& n_in, char* str_link, int lng_link );
+        const int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link );
 
         // あぼーんのクリア
         void clear_abone();
 
         // from_number番から to_number 番までのレスのあぼーん状態を更新
-        void update_abone( int from_number, int to_number );
+        void update_abone( const int from_number, const int to_number );
 
         // あぼーんチェック
-        bool check_abone_res( int number );
-        bool check_abone_id( int number );
-        bool check_abone_name( int number );
-        bool check_abone_word( int number );
-        bool check_abone_chain( int number );
+        const bool check_abone_res( const int number );
+        const bool check_abone_id( const int number );
+        const bool check_abone_name( const int number );
+        const bool check_abone_mail( const int number );
+        const bool check_abone_word( const int number );
+        const bool check_abone_chain( const int number );
 
 
         // 参照数(num_reference)と色のクリア
