@@ -3,6 +3,7 @@
 //#define _DEBUG
 //#define _SHOW_GETBOARD
 //#define _SHOW_BOARD
+//#define _TEST_CACHE
 #include "jddebug.h"
 
 #include "root.h"
@@ -25,18 +26,25 @@
 #include "cache.h"
 #include "httpcode.h"
 #include "environment.h"
+#include "global.h"
 
 #include <sstream>
 #include <cstring>
 #include <sys/types.h> // chmod
 #include <sys/stat.h>
 
+#ifdef _TEST_CACHE
+int cache_hit1 = 0;
+int cache_hit2 = 0;
+int cache_nohit = 0;
+#endif
+
 enum
 {
     SIZE_OF_RAWDATA = 2 * 1024 * 1024  //  bbsmenu.html の最大サイズ
 };
 
-// ルート要素名( list_main.xml )
+// ルート要素名( boards.xml )
 #define ROOT_NODE_NAME "boardlist"
 
 using namespace DBTREE;
@@ -72,6 +80,9 @@ Root::Root()
     // 2chのスレの過去ログ
     set_board( ENVIRONMENT::get_jd2chlog(), "2chスレ過去ログ" );
 
+    // ローカルファイル
+    set_board( URL_BOARD_LOCAL, "ローカルファイル" );
+
     m_board_null = new DBTREE::BoardBase( "", "", "" );
 }
 
@@ -95,6 +106,14 @@ Root::~Root()
     }
 
     if( m_board_null ) delete m_board_null;
+
+#ifdef _TEST_CACHE
+    std::cout << "board cache\n"
+              << "hit1 = " << cache_hit1 << std::endl
+              << "hit2 = " << cache_hit2 << std::endl
+              << "nohit = " << cache_nohit << std::endl
+              << "(hit1+hit2)/total*100 = " << (double)(cache_hit1+cache_hit2)/(cache_hit1+cache_hit2+cache_nohit)*100. << std::endl;
+#endif    
 }
 
 
@@ -120,12 +139,28 @@ BoardBase* Root::get_board( const std::string& url, const int count )
     const int max_count = 50;
 
     // キャッシュ
-    if( url == m_get_board_url && m_get_board ){
-#ifdef _SHOW_GETBOARD
-        std::cout << "hit cache\n";
+    if( m_get_board ){
+
+        if( url == m_get_board_url ){
+#ifdef _TEST_CACHE
+            ++cache_hit1;
 #endif
-        return m_get_board;
+            return m_get_board;
+        }
+        else if( m_get_board->equal( url ) ){
+
+            m_get_board_url = url;
+
+#ifdef _TEST_CACHE
+            ++cache_hit2;
+#endif
+            return m_get_board;
+        }
     }
+#ifdef _TEST_CACHE
+    ++cache_nohit;
+#endif
+
     m_get_board_url = url;
     m_get_board = NULL;
 
@@ -138,7 +173,7 @@ BoardBase* Root::get_board( const std::string& url, const int count )
         if( pos != std::string::npos && pos != 0 ) return m_board_null;
 
         // http:// が含まれていなかったら先頭に追加して再帰呼び出し
-        else if( pos == std::string::npos ){
+        else if( pos == std::string::npos && ! is_local( url ) ){
             BoardBase* board = get_board( "http://" + url , count + 1 );
             m_get_board_url = url;
             return board;
@@ -266,14 +301,8 @@ void Root::download_bbsmenu()
     m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
 
     JDLIB::LOADERDATA data;
+    data.init_for_data();
     data.url = CONFIG::get_url_bbsmenu();
-    data.agent = CONFIG::get_agent_for_data(); 
-    if( CONFIG::get_use_proxy_for_data() ) data.host_proxy = CONFIG::get_proxy_for_data();
-    else data.host_proxy = std::string();
-    data.port_proxy = CONFIG::get_proxy_port_for_data();
-    data.basicauth_proxy = CONFIG::get_proxy_basicauth_for_data();
-    data.size_buf = CONFIG::get_loader_bufsize();
-    data.timeout = CONFIG::get_loader_timeout();
 
     start_load( data );
 }
@@ -389,8 +418,8 @@ void Root::bbsmenu2xml( const std::string& menu )
             // 板として扱うURLかどうかで要素名を変える
             std::string element_name;
             if( CONFIG::use_link_as_board() ) element_name = "board";
-            else if( ( regex.exec( "^http://.*/.*/$", url ) && is_2ch( url ) )
-                     || is_machi( url )
+            else if( ( regex.exec( "^http://.*/.*/$", url )
+			            && ( is_2ch( url ) || is_machi( url ) ) )
                      || is_JBBS( url )
                      || is_vip2ch( url )
                 ) element_name = "board";
@@ -507,6 +536,15 @@ int Root::get_board_type( const std::string& url, std::string& root, std::string
         }
     }
 
+    // ローカルファイル
+    else if( is_local( url ) ){
+
+        root = URL_BOARD_LOCAL;
+        path_board = "/local";
+
+        type = TYPE_BOARD_LOCAL;
+    }
+
     // その他は互換型
     else{
 
@@ -1393,9 +1431,9 @@ void Root::save_movetable()
 //
 // 2ch型のURLかどうか
 //
-bool Root::is_2ch( const std::string& url )
+const bool Root::is_2ch( const std::string& url )
 {
-    std::string hostname = MISC::get_hostname( url );
+    const std::string hostname = MISC::get_hostname( url );
 
     if( ( hostname.find( ".2ch.net" ) != std::string::npos && hostname.find( "info.2ch.net" ) == std::string::npos )
         || hostname.find( ".bbspink.com" ) != std::string::npos ) return true;
@@ -1408,9 +1446,9 @@ bool Root::is_2ch( const std::string& url )
 //
 // JBBS型のURLかどうか
 //
-bool Root::is_JBBS( const std::string& url )
+const bool Root::is_JBBS( const std::string& url )
 {
-    std::string hostname = MISC::get_hostname( url );
+    const std::string hostname = MISC::get_hostname( url );
 
     if( hostname.find( "jbbs.livedoor.jp" ) != std::string::npos
         || hostname.find( "jbbs.shitaraba.com" ) != std::string::npos ) return true;
@@ -1422,9 +1460,9 @@ bool Root::is_JBBS( const std::string& url )
 //
 // まち型のURLかどうか
 //
-bool Root::is_machi( const std::string& url )
+const bool Root::is_machi( const std::string& url )
 {
-    std::string hostname = MISC::get_hostname( url );
+    const std::string hostname = MISC::get_hostname( url );
 
     if( hostname.find( ".machi.to" ) != std::string::npos ) return true;
 
@@ -1435,9 +1473,9 @@ bool Root::is_machi( const std::string& url )
 //
 // vipサービスのURLか
 //
-bool Root::is_vip2ch( const std::string& url )
+const bool Root::is_vip2ch( const std::string& url )
 {
-    std::string hostname = MISC::get_hostname( url );
+    const std::string hostname = MISC::get_hostname( url );
 
     if( hostname.find( ".vip2ch.com" ) != std::string::npos ) return true;
 
@@ -1446,9 +1484,22 @@ bool Root::is_vip2ch( const std::string& url )
 
 
 //
-// 配下の全boardbaseクラスのレスあぼーん状態を更新する
+// ローカルファイルか
 //
-void Root::update_abone_all_board()
+const bool Root::is_local( const std::string& url )
+{
+    if( url.find( "file://" ) != std::string::npos ) return true;
+
+    return false;
+}
+
+
+//
+// スレあぼーん情報を更新した時、全boardbaseクラスに対応するスレ一覧の表示を更新させる
+//
+// CONFIG::set_abone_number_thread() などでグローバル設定をした後などに呼び出す
+//
+void Root::update_abone_thread()
 {
     std::list< BoardBase* >::iterator it = m_list_board.begin();
     for( ; it != m_list_board.end(); ++it ) ( *it )->update_abone_thread();
@@ -1457,7 +1508,7 @@ void Root::update_abone_all_board()
 
 
 //
-// 配下の全boardbaseクラスに、全articlebaseクラスのあぼーん状態の更新をさせる
+// 全boardbaseクラスに、それに属する全articlebaseクラスのあぼーん状態の更新をさせる
 //
 void Root::update_abone_all_article()
 {
