@@ -20,7 +20,7 @@
 using namespace IMAGE;
 
 ImageAreaIcon::ImageAreaIcon( const std::string& url )
-    : ImageAreaBase( url )
+    : ImageAreaBase( url, 0 ) // アイコンは常に Gdk::INTERP_NEAREST
     , m_shown( false )
 {
 #ifdef _DEBUG    
